@@ -123,12 +123,10 @@ class WechatPlugin(notify.NotificationPlugin):
             "text": {
                     "content": '[标题] {}\n[时间] {}\n[{}] {}\n[href]({})'.format(
                         "Sentry {} 项目告警".format(project.slug),
-                        datetime.now(timezone('Asia/Shanghai')
-                                     ).strftime("%Y-%m-%d %H:%M:%S"),
-                        event.get_tag('level').capitalize(
-                        ), event.message.encode('utf8'),
-                        "{}{}events/{}/".format(host,
-                                                group.get_absolute_url())
+                        datetime.now(timezone('Asia/Shanghai')).strftime("%Y-%m-%d %H:%M:%S"),
+                        event.get_tag('level').capitalize(),
+                        event.message.encode('utf8'),
+                        "{}{}events".format(host,group.get_absolute_url())
                     )
             }
         }
